.. _analysis:

=====================
Analysis (`analysis`)
=====================

.. currentmodule:: ctapipe.analysis

Introduction
============

`ctapipe.analysis` contains functions and classes to analyze outputs of
the pipeline and perform validation and verification.

Reference/API
=============

.. automodapi:: ctapipe.analysis.camera


